# A library for internal formation tools used in PaX ULaval formations
Most of the content is to reduce code duplication into our formation and to ease the release of those tools among 
the formations in the platform.
